@@ -100,6 +100,68 @@ def process_single_input(extractor: DocumentExtractor, input_item: str, output_f
         }
 
 
+def handle_login(force_reauth: bool = False) -> int:
+    """Handle login command."""
+    try:
+        from .services.auth_service import get_authenticated_token
+        
+        print("\n🔐 DocStrange Authentication")
+        print("=" * 50)
+        
+        token = get_authenticated_token(force_reauth=force_reauth)
+        if token:
+            print("✅ Authentication successful!")
+            
+            # Get cached credentials to show user info
+            try:
+                from .services.auth_service import AuthService
+                auth_service = AuthService()
+                cached_creds = auth_service.get_cached_credentials()
+                
+                if cached_creds and cached_creds.get('auth0_direct'):
+                    print(f"👤 Logged in as: {cached_creds.get('user_email', 'Unknown')}")
+                    print(f"👤 Name: {cached_creds.get('user_name', 'Unknown')}")
+                    print(f"🔐 Via: Auth0 Google Login")
+                    print(f"🔑 Access Token: {token[:12]}...{token[-4:]}")
+                    print("💾 Credentials cached securely")
+                else:
+                    print(f"🔑 Access Token: {token[:12]}...{token[-4:]}")
+                    print("💾 Credentials cached securely")
+            except:
+                print(f"🔑 Access Token: {token[:12]}...{token[-4:]}")
+                print("💾 Credentials cached securely")
+            
+            print("\n💡 You can now use DocStrange cloud features without specifying --api-key")
+            print("🌐 Your CLI is authenticated with the same Google account used on docstrange.nanonets.com")
+            return 0
+        else:
+            print("❌ Authentication failed.")
+            return 1
+    except ImportError:
+        print("❌ Authentication service not available.", file=sys.stderr)
+        return 1
+    except Exception as e:
+        print(f"❌ Authentication error: {e}", file=sys.stderr)
+        return 1
+
+
+def handle_logout() -> int:
+    """Handle logout command."""
+    try:
+        from .services.auth_service import clear_auth
+        
+        clear_auth()
+        print("✅ Logged out successfully.")
+        print("💾 Cached authentication credentials cleared.")
+        return 0
+    except ImportError:
+        print("❌ Authentication service not available.", file=sys.stderr)
+        return 1
+    except Exception as e:
+        print(f"❌ Error clearing credentials: {e}", file=sys.stderr)
+        return 1
+
+
 def main():
     """Main CLI function."""
     parser = argparse.ArgumentParser(
@@ -107,6 +169,13 @@ def main():
         formatter_class=argparse.RawDescriptionHelpFormatter,
         epilog="""
 Examples:
+  # Authentication (browser-based login)
+  docstrange login                    # One-click browser login
+  docstrange login --reauth          # Force re-authentication
+  
+  # Start web interface
+  docstrange web                     # Start web interface at http://localhost:8000
+  
   # Convert a PDF to markdown (default cloud mode)
   docstrange document.pdf
 
@@ -261,6 +330,24 @@ docstrange document.pdf --model nanonets --output csv
         help="Enable verbose output"
     )
     
+    parser.add_argument(
+        "--login",
+        action="store_true",
+        help="Perform browser-based authentication login"
+    )
+    
+    parser.add_argument(
+        "--reauth",
+        action="store_true", 
+        help="Force re-authentication (use with --login)"
+    )
+    
+    parser.add_argument(
+        "--logout",
+        action="store_true",
+        help="Clear cached authentication credentials"
+    )
+    
     args = parser.parse_args()
     
     # Handle version flag
@@ -280,12 +367,38 @@ docstrange document.pdf --model nanonets --output csv
         print_supported_formats(extractor)
         return 0
     
+    # Handle authentication commands
+    # Check if first argument is "login" command
+    if args.input and args.input[0] == "login":
+        force_reauth = "--reauth" in sys.argv
+        return handle_login(force_reauth)
+    
+    # Handle web command
+    if args.input and args.input[0] == "web":
+        try:
+            from .web_app import run_web_app
+            print("Starting DocStrange web interface...")
+            print("Open your browser and go to: http://localhost:8000")
+            print("Press Ctrl+C to stop the server")
+            run_web_app(host='0.0.0.0', port=8000, debug=False)
+            return 0
+        except ImportError:
+            print("❌ Web interface not available. Install Flask: pip install Flask", file=sys.stderr)
+            return 1
+    
+    # Handle login flags
+    if args.login or args.logout:
+        if args.logout:
+            return handle_logout()
+        else:
+            return handle_login(args.reauth)
+    
     # Check if input is provided
     if not args.input:
         parser.error("No input specified. Please provide file(s), URL(s), or text to extract.")
     
-    # Cloud mode is default and works without API key (rate-limited)
-    # API key provides increased rate limits
+    # Cloud mode is default. Without login/API key it's limited calls.
+    # Use 'docstrange login' (recommended) or --api-key for 10k docs/month for free.
     
     # Initialize extractor
     extractor = DocumentExtractor(
@@ -300,8 +413,8 @@ docstrange document.pdf --model nanonets --output csv
         print(f"Initialized extractor in {mode} mode:")
         print(f"  - Output format: {args.output}")
         if mode == "cloud":
-            has_api_key = bool(args.api_key or extractor.api_key)
-            print(f"  - API key: {'provided' if has_api_key else 'not provided (rate-limited)'}")
+            has_api_or_auth = bool(args.api_key or extractor.api_key)
+            print(f"  - Auth: {'authenticated (10k/month) free calls' if has_api_or_auth else 'not authenticated (limited free calls)'}")
             if args.model:
                 print(f"  - Model: {args.model}")
         else:
